#ifndef PUNTATEMAIN_H
#define PUNTATEMAIN_H

#include <QMainWindow>
#include <QDialog>

namespace Ui {
class PuntateMain;
}

class PuntateMain : public QMainWindow
{
    Q_OBJECT
    
public:
    explicit PuntateMain(QWidget *parent = 0);
    ~PuntateMain();

private slots:

    void on_pushButton_22_clicked();

    void on_stream1_clicked();

    void on_down2_clicked();

    void on_stream2_clicked();

    void on_down3_clicked();

    void on_stream3_clicked();

    void on_down4_clicked();

    void on_stream4_clicked();

    void on_down5_clicked();

    void on_stream5_clicked();

    void on_down6_clicked();

    void on_stream6_clicked();

    void on_down7_clicked();

    void on_stream7_clicked();

    void on_down8_clicked();

    void on_stream8_clicked();

    void on_down9_clicked();

    void on_stream9_clicked();

    void on_down10_clicked();

    void on_stream10_clicked();

    void on_down11_clicked();

    void on_stream11_clicked();

    void on_down12_clicked();

    void on_stream12_clicked();

    void on_down13_clicked();

    void on_stream13_clicked();
    
    void on_actionPuntate_Scaricate_triggered();

    void on_down13_2_clicked();

    void on_stream13_2_clicked();

    void on_down15_clicked();

    void on_stream15_clicked();

    void on_down16_clicked();

    void on_stream16_clicked();

    void on_down17_clicked();

    void on_stream17_clicked();

    void on_down18_clicked();

    void on_stream18_clicked();

    void on_down19_clicked();

    void on_stream19_clicked();

    void on_down20_clicked();

    void on_stream20_clicked();

private:
    Ui::PuntateMain *ui;
};

#endif // PUNTATEMAIN_H
